function [D,timetaken]=computeD2(q,alphas,normalize)
%compute the discretized transition matrix D (not necessarily square)
%SYNTAX
%[D,timetaken]=computeD2(q,alphas,normalize)
%INPUTS
%q is an m x 3 array whos rows are the mesh points at which we estimated parameters of
%local Dirichlet distributions
%alphas is an n x 3 array whose rows are parameters for the local Dirichlet
%distribution estimated at the corresponding mesh point (row of q)
%if normalize is 1, normalize D so each column integrates to 1 by rectangle rule (useful if
%we have equal weights at mesh points)
%OUTPUTS
%D is an m x n matrix with i,jth entry D(p_i|q_j), the Dirichlet density
%for transition to location p_i from q_j, computed at the same set of mesh points q for p_i and q_j.
%If normalize is 1, D is normalized so that the columns
%should sum to 1 (although they may not do so exactly because of numerical
%errors)
%timetaken is clock time used.
%USES
%ddirichlet2.m

if nargin<3
    normalize=0;
end

tzero=clock;
m=size(q,1);
n=size(alphas,1);
D=zeros(m,n);

for jj=1:n%for each mesh point qj
%    Z=prod(gamma(alphas(jj,:)))/gamma(sum(alphas(jj,:)));%compute the normalization constant
    logZ=sum(gammaln(alphas(jj,:)))-gammaln(sum(alphas(jj,:)));%compute the normalization constant
    for ii=1:m%for each mesh point pi
        D(ii,jj)=ddirichlet2(q(ii,:),alphas(jj,:),logZ);%evaluate D(p_i|q_j). VECTORIZING DDIRICHLET MIGHT SPEED THIS UP
    end
end
if normalize
    D=D/(2*m);
end
timetaken=etime(clock,tzero);