function coral_triangle3(vals,reefid,year,names,newfig,fontsize,markersize)
%scatter plot of algae and coral cover on triangular coordinates
%this version: solid lines connect samples on same reef at one
%year intervals.
%SYNTAX
%coral_triangle3(vals,reefid,year,names,newfig,fontsize,markersize)
%INPUTS
%vals is an array with cols alpha,beta,gamma for each point (row):
%alpha+beta+gamma=1 in any row. alpha=coral, beta=algae, gamma=others.
%reefid is a vector: each entry is the reefid for a given set of values
%year is a vector: years in which observations were made
%names (optional) is a cell array of reef names to put at the start of each
%sequence
%newfig (optional): if 1 (default), plot on a new figure
%fontsize (optional): font size for axis labels
%markersize (optional): marker size for points
%OUTPUTS
%ternary plot
%[0 1 0] will be at top vertex (all algae)
%[1 0 0] at RH vertex (all coral)
%[0 0 1] at LH vertex (all others)
%For each unique reef id, the starting point of each run of one-year observation intervals is plotted as a blue circle and
%the final point is a red dot. Other points are black dots, and they
%are joined by black lines.
%USES
%xytoternary.m
%NOTES
%Input order is different from coral_triangle2.m (where it was
%algae,coral,others). This way round is more logical when used with
%xytoternary.m
%Colors also changed: blue circle at start, red dot at end is opposite way
%from previous versions (because the red dots stand out more, which is
%useful when we want to know final state)

if nargin<4
    names={};
end
if nargin<5
    newfig=1;
end
if nargin<6
    fontsize=18;
end
if nargin<7
    markersize=10;
end

a=2/3*sin(pi/3);
xv=[-a a 0 -a];%triangle edges
yv=[-1/3 -1/3 2/3 -1/3];

if newfig
    figure(1);
    clf;
end
plot(xv,yv,'k-');%plot edges
axis equal;
axis off;
hold on;

uniqueid=unique(reefid);
for i=1:length(uniqueid)%plot each sample
    alpha=vals(logical(reefid==uniqueid(i)),1);
    beta=vals(logical(reefid==uniqueid(i)),2);
    yr=year(logical(reefid==uniqueid(i)));
    t=xytoternary([alpha,beta]);
    x=t(:,1);
    y=t(:,2);
    if ~isempty(names)
        nm=names(logical(reefid==uniqueid(i)));
    end
    xl=length(x);
    if xl>1
        %plot(x,y,'k.:');%if we do this, points on the same reef that aren't in
        %consecutive years are joined by dotted lines
        plot(x,y,'k.','markersize',markersize);
    
        dy=diff(yr);
        for j=1:length(dy)
            if dy(j)==1%plot lines only if observation interval is one year
                plot([x(j) x(j+1)],[y(j) y(j+1)],'k-'); 
            else%plot red end marker, then blue start marker
                plot(x(j),y(j),'r.','markersize',markersize);
                plot(x(j+1),y(j+1),'bo','markersize',markersize);
                if ~isempty(names)
                    text(x(j+1),y(j+1),[nm(j+1),num2str(yr(j+1))],'fontsize',8);
                end
            end
        end
        plot(x(1),y(1),'bo','markersize',markersize);%blue at start
        plot(x(xl),y(xl),'r.','markersize',markersize);%red at end
        if ~isempty(names)
            text(x(1),y(1),[nm(1),num2str(yr(1))],'fontsize',8);
        end
    end
end;

label_ternary_axes({'coral','algae','others'},fontsize);%axis labelling
set(gca,'linewidth',1.5);
