function fitstruct = dirMLlocKerNeigh(x0,x,y,initval,k,Ker,Dist)

% local maximum likelihood estimation at x0 for parameters of the Dirichlet
% distribution of the future state of the reef given its current state 
%
% Parameters alpha are assumed to be a smooth function of the current state
% and are approximated locally by a linear function; exponential function
% is used to ensure that all alphas are positive
%
%SYNTAX
%fitstruct = dirMLlocKerNeigh(x0,x,y,initval,k,Ker,Dist)
%
% INPUT
%
% x0 - point on a simplex at which to estimate the parameters
% x - 3 column matrix with the initial state of the reef
% y - state of the reef after (approximatelly) one year (so that each row
%   in y corresponds to a row in x)
% initval - initial value for optimisation algorithm; this should be a
%   column vector with 9 elements
% k - number of  neighbours (if k>1), or proportion of nieghbours (if k<1)
%           to be used in local estimation 
% Ker - kernel function (currently probably only 'epanechnikov' works)
% Dist - a distence function on the simplex; two options 'distTaxi' or
%   'distAt3'
%
% OUTPUT
% fitstruct is a structure with the following fields:
% estims: estimated parameters of the Dirichlet distribution
% negl: negative log likelihood
% npoints: number of points with nonzero weight
% exitflag: optimizer status
% optoutput: structure of optimizer information
% grad: gradient at solution
% hessian: hessian at solution
%
%USES
%distTaxi.m
%distAl3.m
%epanechnikov.m
%
%NOTES
%MS 29/5/10: added zero offsetting as in cross_valid_neigh.m

%%%%% CODE

n1 = size(y,1);

% distances from x0 to all points in x
dist0 = feval( Dist, repmat(x0,n1,1), x );

% find h for k nearest neighbours
sortdist0 = sort(dist0);

%%%MS 12/7/11L this fails with k=1 or very close to 1%%%%%%%%%%%%%
% if (k>1), 
%     h = sortdist0(k+1);
% else 
%     h = sortdist0(floor(k*n1)+1);
% end
h=sortdist0(min(n1,floor(k*n1)+1));%MS 12/7/11
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% weights for all points in x
W = feval( Ker, dist0, h);
npoints=sum(W>0);%number of points contributing to estimate

% offset zeros
[id1,id2] = find( y == 0 );
y(id1,id2) = 1e-12;
y(id1,1:(id2-1)) = y(id1,1:(id2-1)) - .5e-12;
y(id1,(id2+1):3) = y(id1,(id2+1):3) - .5e-12;


logy = log(y);


[estims,negl,exitflag,optoutput,grad,hessian] = fminunc(@(params) loglik(x0,x,logy,params,W,n1),initval,...
    optimset('MaxFunEvals',5000,'MaxIter',5000,'Tolx',1e-6,'TolFun',1e-6,'largescale','off','display','off'));


estims = exp(estims(1:3:end));

fitstruct=struct('estims',estims,'negl',negl,'npoints',npoints,'exitflag',exitflag,'optoutput',optoutput,'grad',grad,'hessian',hessian);


%%%%%%% INTERNAL FUNCTION

% negative log-likelihood
function l = loglik(x0,x,logy,params,W,n1)
% calculate negative log-likelihood for Dirichelet distribution

% define variables
Params = reshape(params,3,3);
alphas = zeros(n1,3);

% alphas are a function of the parameters and current state
for k = 1:3,
    alphas(:,k) = exp( Params(1,k) + Params(2,k) .* ( x(:,1) - x0(1) ) +...
        Params(3,k) .* ( x(:,2) - x0(2) ) );
end

logB = sum(gammaln(alphas),2) - gammaln(sum(alphas,2));

% negative loglikelihood
l = (logB - diag((alphas - 1) * logy'))' * W;

if isnan(l)%numerical problems
    l=1e6;%if l didn't evaluate, set it to a very large value (for our problem)
end

% Epanechnikov: made this into an external function
%function y = epanechnikov(x,s)
%X = x/s;
%X(abs(X)>1) = 1;
%y = 0.75 * (1 - X.^2)/s;