function [f0,gg,gv,Gp,v,K,J,D]=distmovie(X,Y,tmax,nGauss,ncut,k_cv)
%create a movie of how the predicted distribution changes over time
%SYNTAX
%[f0,gg,gv,Gp,v,K,J,D]=distmovie(X,Y,tmax,nGauss,ncut,k_cv)
%INPUTS
%X is a matrix where each row is an observation, with columns:
%reefid year coral algae others
%for observations that have another observation one year later on the same
%reef
%reefid is a unique number for each combination of reef and site
%coral is Hard coral as a proportion
%algae is Erect algae as a proportion
%others is 1-Hard coral-Erect algae
%Y is a matrix in the same form, but such that row i of Y corresponds to
%the state of the reef in row i of X one year later
%(these come from readMcClanahan.m, readBruno.m, etc)
%tmax is max time step
%nGauss is the square root of the number of Gauss points
%k_cv is the proportion of points to include as neighbours in local linear estimation, chosen by
%cross-validation
%OUTPUTS
%f0 is a matrix whose rows are the latest values of coral, algae, and
%others observed on each reef
%gg is a matrix with entry i,j the density at the ith Gauss point at time j
%gv is a matrix with entry i,j the density at the ith visual grid point at time j
%Gp is a matrix of Gauss points (each row is a point, cols are coral,
%algae, free space)
%v is a matrix of visual grid points (each row is a point, cols are coral,
%algae, free space)
%K is transition kernel among Gauss points
%J is transition kernel from Gauss points to visual grid points
%D is weight matrix for Gauss points
%Use makedistmovie.m to plot the results
%USES
%simplexquad.m
%estimate_meshalphaNeigh.m
%ddirichlet2.m
%generate_meshpoints.m
%computeD2.m
%plot_coral_distribution

%initialize at time 0: find the most recent observation from each reef
ri=unique(Y(:,1));
n0=length(ri);
f0=zeros(n0,3);
for i=1:n0
    Ysub=Y(logical(Y(:,1)==ri(i)),:);%all the rows with this reef id
    maxy=max(Ysub(:,2));%latest observation with this reefid
    f0(i,:)=Ysub(Ysub(:,2)==maxy,3:5);
end

[Gp,Gw]=simplexquad(nGauss,2); %n^2 Gauss points
Gp=[Gp 1-sum(Gp,2)]; %add third component

[qg,v]=generate_meshpoints(ncut);%find grid points for visual representation

%find density at Gauss points and visual grid points at time 1
ngp=size(Gp,1);
nvp=size(qg,1);
gg=zeros(ngp,tmax);
gv=zeros(nvp,tmax);
[alphas,exitflags,Al]=estimate_meshalphaNeigh(f0,X,Y,zeros(9,1),k_cv,'epanechnikov','distTaxi');%estimate Dirichlet parameters at the points in f0
for i=1:n0
    logZ=sum(gammaln(alphas(i,:)))-gammaln(sum(alphas(i,:)));%compute the normalization constant
    for j=1:ngp%compute transition kernel to each of the Gauss points
        gg(j,1)=gg(j,1)+ddirichlet2(Gp(j,:),alphas(i,:),logZ);%evaluate D(g_j|x_i)
    end
    for k=1:nvp%compute transition kernel to each of the visual grid points
        gv(k,1)=gv(k,1)+ddirichlet2(qg(k,:),alphas(i,:),logZ);%evaluate D(gv_j|x_i)
    end
end
gg(:,1)=gg(:,1)/n0;
gv(:,1)=gv(:,1)/n0;
plot_coral_distribution(v,gv(:,1));%plot the resulting distribution at time 1
[galphas,gexitflags,gAl]=estimate_meshalphaNeigh(Gp,X,Y,zeros(9,1),k_cv,'epanechnikov','distTaxi');%estimate Dirichlet parameters at the Gauss points
K=computeD2(Gp,galphas,0);%transition kernel matrix among Gauss points: don't normalize
J=computeD2(qg,galphas,0);%compute the kernel for transitions from Gauss points to visual grid points. Don't normalize
D=diag(Gw);%diagonal matrix of Gauss weights
for t=2:tmax%for times 2 to tmax
    gg(:,t)=K*D*gg(:,t-1);%find density at Gauss points
    gv(:,t)=J*D*gg(:,t);%find density at visual grid points using Nystrom
    %plot_coral_distribution(v,gv(:,t));%plot the current density
end