%example of methods used in Zychaluk et al, Modelling regional coral reef
%dynamics without mechanistic assumptions
%To run this, type example_script at the Matlab command prompt. Requires
%the curve fitting, optimization, and statistics toolboxes
%Tested with
%MATLAB Version 7.9.0.529 (R2009b)
%Operating System: Linux 2.6.26-2-686 #1 SMP Mon Aug 30 07:01:57 UTC 2010 i686
%Curve Fitting Toolbox                                 Version 2.1        (R2009b)
%Optimization Toolbox                                  Version 4.3        (R2009b)
%Statistics Toolbox                                    Version 7.2        (R2009b)
%
%Matthew Spencer, School of Environmental Sciences, University of Liverpool
%2 August 2011
%
%Makes use of the function simplexquad.m by Greg von Winckel, distributed under the BSD
%license, given below:
%
% Copyright (c) 2009, Greg von Winckel
% All rights reserved.
% 
% Redistribution and use in source and binary forms, with or without 
% modification, are permitted provided that the following conditions are 
% met:
% 
%     * Redistributions of source code must retain the above copyright 
%       notice, this list of conditions and the following disclaimer.
%     * Redistributions in binary form must reproduce the above copyright 
%       notice, this list of conditions and the following disclaimer in 
%       the documentation and/or other materials provided with the distribution
%       
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
% AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
% IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
% ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
% LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
% CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
% SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
% INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
% CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
% ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
% POSSIBILITY OF SUCH DAMAGE.
%

clear
skip=zeros(8,1);%set to 1 for any step we want to skip:
%step 1: generate simulated data (under a stochastic model with two
%attractors)
%step 2: estimate stationary distribution
%step 3: display stationary distribution from data in file
%step 4: calculate residuals
%step 5: plot residuals
%step 6: calculate damping ratio
%step 7: plot differences between current and equilibrium distribution over
%a few time steps
%step 8: plot estimated Dirichlet alphas
%note that because we reload data from file, subsequent steps are likely to
%be run as well (depending on what was saved in the file)

fsize=18;
msize=3;

%parameters used in Figure 3a of Mumby et al 07
g=0.3;
r=1;
a=0.1;
gamma=0.8;
d=0.44;

%Euler-Maruyama settings
N=2e6;
T=20;
thin=1e4;
beta=[0.4 0.4];
ncut=8;

np=5000;%number of points in multinomial sample of reef composition: m=5000 is high effort

if ~skip(1)%generate simulated data based on initial values from real data
    startvals=dlmread('startvals.txt','\t',1,0);
    X0=startvals(:,1:3);%sets of initial values
    X0s=sum(X0,2);
    X0s=X0s(:,ones(1,3));
    X0=X0./X0s;%make sure each set of initial values sums to 1
    rl=startvals(:,4);%length of time series to generate
    Nstep=N/T;
    Tscale=5;%number of time units in EM per year

    %generate a simulated data set using a stochastic version of the Mumby
    %et al 07 differential equation model
    disp('Generating simulated data');%expect this to take a few seconds
    [simdata,simreefid,simyear]=simulatefromstart(X0,rl,a,g,gamma,r,d,beta,Nstep,Tscale);
    simdata=multinomialmeasurementerror(simdata,np);%multinomial measurement error
    [simX,simY]=constructXY(simreefid,simdata,simyear);
    
    %plot the raw data
    coral_triangle3(simdata,simreefid,simyear,[],1,fsize,msize);
    
    %model-free summary
    figure(2);
    clf;
    modelfree_stats(5,simX,simY,0);
    
    %summarize perturbations
    p=getperturbation(simX,simY);
    Cnorm=getCnorm(p);
    disp(['mean perturbation ',num2str(mean(Cnorm)), ', sd ',num2str(std(Cnorm))]);
    
    save simdata
end
   
if ~skip(2)%estimate stationary distribution
    load simdata
    disp('Cross-validation');
    simk_cv = cross_valid_neigh(simX(:,3:5),simY(:,3:5),'epanechnikov','distTaxi');%estimate proportion of neighbours to include by cross-validation: expect this to take 15 min or so
    n=40;
    [Gp,Gw]=simplexquad(n,2); %n^2 Gauss points
    Gp=[Gp 1-sum(Gp,2)]; %add third component
    disp('Local linear estimation of Dirichlet parameters on grid');
    [D,alphas,exitflags,Al,kv,timetaken,done]=protect_estimatemeshalphaNeigh(Gp,simX,simY,simk_cv,'epanechnikov','distTaxi');%expect this to take 10 min or so
    save simdata
    Dw=D*diag(Gw); %multiply by Gauss weights
    [eigvec,eigval]=eig(Dw); %eigenvalue approximation
    disp(['Largest eigenvalue: ',num2str(max(diag(eigval))),'. Should be 1, but data with two attractors hard to integrate.']); %should be 1: may not be very close for simulated data with two attractors: hard to integrate
    m=100;
    disp('Approximating equilibrium distribution');
    [fx,q]=Nystrom_distribution(m,eigvec,eigval,alphas,Gw); %Use Nystrom extension to approximate eigenfunction on a regular mesh
    caxis([0 25]) %need this to see the detail: used [0 25] in paper: extent of bimodality will vary between simulation runs. Smaller max colour values make it easier to see whether the estimated distribution is bimodal
    [intf,cx,S,detS,rootdetS]=simplexsummary(eigvec,eigval,Gp,Gw);%summarize equilibrium distribution
    disp('Summary of equilibrium distribution')
    disp(['Centre: ',num2str(cx)]);
    disp(['Square root generalized variance: ',num2str(rootdetS)]);
    save simdata
end

if ~skip(3)%load and view the estimated stationary distribution
    load simdata
    ccax=[0 25];%truncate the colour scale otherwise we see little detail
    Nystrom_fromfile(m,fx,1,fsize,ccax,0);
end

if ~skip(4)%calculate residuals
    load simdata
    disp('Local linear estimation of Dirichlet parameters at observations');
    [ralphas,rexitflags]=estimate_alpha_neigh(simX,simY,simk_cv,'epanechnikov','distTaxi');%estimate parameters at observations: might take a minute or so
    [R,C,EY]=Dirichlet_residuals(simY(:,3:5),ralphas);%calculate standardized and composite residuals
    save simdata
end

if ~skip(5)%plot residuals
    load simdata
    residsbytime2(simY,C,R);%plot residuals by time: we don't have real years attached to the simulated data
    plot_lagged_residuals(simX,R,0.4,[2,3],fsize);%residuals by state and lagged state
    residbyreefid(simX,C,R,[],[4 5]);%residuals by reef id
end

if ~skip(6)%calculate damping ratio
    load simdata
    temp=sort(diag(eigval));
    lambda1=temp(end);
    lambda2=temp(end-1);
    dr=lambda1/abs(lambda2);
    disp(['damping ratio ',num2str(dr)]);
end

if ~skip(7)%plot differences between current and stationary distributions
    load simdata
    tmax=3;
    disp('Calculating differences between current and stationary distribution');
    [f0,gg,gv,Gp,v,K,J,D]=distmovie(simX,simY,tmax,n,m,simk_cv);%expect this to take about 15 minutes
    makedistmovie2(f0,v,gv,fx,3);%latest point on each reef + first 3 years predicted
    save simdata
end

if ~skip(8)%plot Dirichlet alphas
    load simdata
    m=100;
    [Al,q,v] = plotalphas2(simX,simY,simk_cv,m); 
    ccaxall=[0 25];%truncate as for stationary distributions
    
    figure(1);
    clf;
    subplot(3,1,1)
    plot_coral_distribution(v,Al(:,1),0,fsize,ccaxall,0);%plot the resulting pattern of alphas
    panel_label('a: \alpha_1',fsize,-0.2,0.3);
    subplot(3,1,2)
    plot_coral_distribution(v,Al(:,2),0,fsize,ccaxall,0);%plot the resulting pattern of alphas
    panel_label('b: \alpha_2',fsize,-0.2,0.3);
    subplot(3,1,3)
    plot_coral_distribution(v,Al(:,3),0,fsize,ccaxall,0);%plot the resulting pattern of alphas
    panel_label('c: \alpha_3',fsize,-0.2,0.3);    
    
end