function [centroids,v]=modelfree_stats(m,X,Y,newfig,fontsize,markersize)
%model-free summary of mean direction of movement by dividing the simplex
%into triangles and finding the mean vector for each triangle:
%This tries to find ways of summarizing these mean vectors
%This version also uses metric centre (closure of geometric means) rather
%than arithmetic mean as a measure of centre
%SYNTAX
%[centroids,v]=modelfree_stats(m,X,Y,newfig,fontsize,markersize)
%INPUTS
%m is the number of cutpoints on each edge of the simplex
%X is a matrix where each row is an observation, with columns:
% reefid year coral algae others
% for observations that have another observation one year later on the same
% reef
%Y is a matrix in the same form, but such that row i of Y corresponds to
% the state of the reef in row i of X one year later
%newfig (optional, default 1) is 1 if we want a new plot
%fontsize (optional) is font size for axis labels
%markersize (optional) is marker size for points
%OUTPUTS
%centroids is an (m+1)^2 x 3 matrix of metric centres for the points
%recorded in a given triangle (row) of the simplex. Cols are coral, algae
%and others coordinates of the centre
%v is an (m+1)^2 x 9 matrix. For a given row i of q, cols 1:3, 4:6, and
%7:9 of the corresponding row of v are the vertices of the triangle
%generate_meshpoints.m
%xytoternary.m
%Also produces a ternary plot in which the mean vector for each triangle
%is shown as a black line starting at the centre (blue circle) of the
%points in that triangle

if nargin<4
    newfig=1;
end
if nargin<6
    fontsize=18;
end

if nargin<6
    markersize=10;
end

[q,v]=generate_meshpoints(m);%generate a regular grid of mesh points

a=2/3*sin(pi/3);
xv=[-a a 0 -a];%triangle edges
yv=[-1/3 -1/3 2/3 -1/3];

if newfig
    figure(1);
    clf;
end
axis equal;
axis off;
hold on;
ntri=(m+1)^2;
centroids=zeros(ntri,3);

%exclude any data with a zero component
indz=logical(sum(X(:,3:5)==0,2)==0 & sum(Y(:,3:5)==0,2)==0);
X=X(indz,:);
Y=Y(indz,:);

for ii=1:ntri%for each triangle
    xt=[xytoternary(v(ii,1:3));xytoternary(v(ii,4:6));xytoternary(v(ii,7:9));xytoternary(v(ii,1:3))];
    plot(xt(:,1),xt(:,2),'color',[0.7 0.7 0.7]);%draw the small triangle
    if(v(ii,1)<v(ii,4))%this triangle is point-up
        ind=(X(:,3)>=v(ii,1) & X(:,4)>=v(ii,5) & X(:,5)>=v(ii,9));%find the points in the triangle
    else%point-down
        ind=(X(:,3)<v(ii,1) & X(:,4)<v(ii,5) & X(:,5)<v(ii,3));%find the points in the triangle
    end
    xp=xytoternary(X(ind,3:5));
    plot(xp(:,1),xp(:,2),'.','Color',[0.7 0.7 0.7],'markersize',markersize);%plot these points

    vec=Y(ind,3:5)./X(ind,3:5);
    vs=sum(vec,2);
    vs=vs(:,ones(1,3));
    vec=vec./vs;%perturbation vector
    
    %check we have the correct perturbation
    %checky=X(ind,3:5).*vec;
    %csum=sum(checky,2);
    %csum=csum(:,ones(1,3));
    %checky=checky./csum;
    %checky-Y(ind,3:5)
    
    
    
    cx=geomean(X(ind,3:5),1);
    cx=cx/sum(cx);%Aitchison's measure of centre
    centroids(ii,:)=cx;
    
 
    cy=geomean(Y(ind,3:5,1),1);
    cy=cy/sum(cy);
    
    mp=[xytoternary(centroids(ii,:));xytoternary(cy)];
    plot(mp(1,1),mp(1,2),'bo','markersize',markersize);
    plot(mp(2,1),mp(2,2),'r.','markersize',markersize);
    plot(mp(:,1),mp(:,2),'k-','markersize',markersize);
end

plot(xv,yv,'k-');%plot edges
label_ternary_axes({'coral','algae','others'},fontsize);%axis labelling
set(gca,'linewidth',1.5);

    
    