function [D,alphas,exitflags,Al,kv,timetaken,done]=protect_estimatemeshalphaNeigh(Gp,X,Y,k_cv,Ker,Dist)
%estimate Dirichlet parameters for Gauss points. If necessary, increase
%proportion of points in neighbourhood for points where the Dirichlet
%distribution evaluates to NaN
%SYNTAX
%[D,alphas,exitflags,Al,kv,timetaken,done]=protect_estimatemeshalphaNeigh(Gp,X,Y,k_cv,Ker,Dist)
%INPUTS
%Gp is an n x 3 matrix, with row j being the coordinates of a point
%on the triangular simplex.
%X is a matrix where each row is an observation, with columns:
% reefid year coral algae others
% for observations that have another observation one year later on the same
% reef
%Y is a matrix in the same form, but such that row i of Y corresponds to
% the state of the reef in row i of X one year later
%k_cv is the proportion of observations to include in the local neighbourhood
%for each mesh point (e.g. an estimate from cross-validation)
%%Ker - kernel function (currently probably only 'epanechnikov' works)
%Dist - a distance function on the simplex; two options 'distTaxi' or
%'distAt3'
%OUTPUTS
%D is an m x m matrix with i,jth entry D(Gp_i|Gp_j), the Dirichlet density
%for transition to location Gp_i from Gp_j
%alphas is an n x 3 array of the estimated Dirichlet parameters
%alpha1, alpha2, alpha3 (columns) for each point (row) in q
%exitflags is an n x 1 array of the values of the optimizer exit flags from
%the fitstructs in Al (positive values mean it probably worked OK)
%Al is an n x 1 cell array of structures. Element j is the structure
%fitstruct estimated by dirMLlocKer2.m for point q_j.
%kv is a vector of the value of k (proportion of neighbours used) for each
%of the points in Gp
%timetaken is clock time used
%done is exit status: 1 means succeeded, -1 means reached k=1 for some
%points without eliminating all problems with D
%USES
%estimate_meshalphaNeigh.m
%computeD2.m

tzero=clock;
[alphas,exitflags,Al]=estimate_meshalphaNeigh(Gp,X,Y,zeros(9,1),k_cv,Ker,Dist); %estimate Dirichlet parameters for each Gauss point: takes a few minutes (I think zeros is the right starting point because it's flat)
D=computeD2(Gp,alphas); %compute transition kernel at each Gauss point combination
prob_ind=find(sum(isnan(D))>0);%any Gauss points with problems using initial estimate
done=isempty(prob_ind);
kv=k_cv*ones(1,size(Gp,1));
k_p=k_cv;
while done==0
    k_p=k_p+0.01;%increase proportion of neighbours for these Gauss points 
    kv(prob_ind)=k_p;
    [alphas_p,exitflags_p,Al_p]=estimate_meshalphaNeigh(Gp(prob_ind,:),X,Y,zeros(9,1),k_p,Ker,Dist);%re-estimate parameters for these points
    alphas(prob_ind,:)=alphas_p;
    Al(prob_ind)=Al_p;
    exitflags(prob_ind)=exitflags_p;
    D=computeD2(Gp,alphas); %compute transition kernel at each Gauss point combination
    prob_ind=find(sum(isnan(D))>0);%any columns of D in which Dirichlet evaluates to NaN?
    done=isempty(prob_ind);%still some Gauss points with problems?
    if k_p>1.0%fail: proportion of neighbours included exceeds 1
        done=-1;
    end
end
timetaken=etime(clock,tzero);
