function residbyreefid(X,C,R,idmap,fignums)
%plot residuals by reef
%SYNTAX
%residbyreefid(X,C,R,idmap,fignums)
%INPUTS
%X is a matrix where each row is an observation, with columns:
% reefid year coral algae others
% for observations that have another observation one year later on the same
% reef
%C is an n x 1 vector of composite residuals for each of the observations
%in X
%R is an n x 3 matrix of standardized univariate residuals for each of the
%observations in X
%idmap (optional) is a cell array with reef names in col 1, reef ids in col
%2 (use the names if idmap supplied)
%fignums (optional) is figure numbers in which to plot output
%OUTPUTS
%A graph of composite residuals for each reef, sorted in descending order
%of median composite residual (shown as a red circle)
%and a graph with each of the three standardized univariate residuals,
%sorted in the same order

    if nargin<4
        idmap=[]; 
    end
    if nargin<5
        fignums=[1 2];
    end
    figure(fignums(1));
    clf;
    uid=unique(X(:,1));
    nreef=length(uid);

    %sort by median composite residual
    cm=zeros(nreef,1);
    for ii=1:nreef
        ind=logical(X(:,1)==uid(ii));%find all the observations on this reef
        cm(ii)=median(C(ind));%find the median composite residual for this reef
    end
    [isort,sortind]=sort(cm);
    plotsortedresids(X,C,uid,sortind,nreef,'Composite residual','Reef id',[],idmap);
    %we can also plot each standardized residual, sorted by median
    %composite residual. Haven't made these look nice yet
    figure(fignums(2));
    clf;
    subplot(1,3,1);
    plotsortedresids(X,R(:,1),uid,sortind,nreef,'\itr_{i1}','Reef id','a: coral residuals',idmap);
    subplot(1,3,2);
    plotsortedresids(X,R(:,2),uid,sortind,nreef,'\itr_{i2}',[],'b: algae residuals',idmap);
    subplot(1,3,3);
    plotsortedresids(X,R(:,3),uid,sortind,nreef,'\itr_{i3}',[],'c: other residuals',idmap);

end

function plotsortedresids(X,residcol,uid,sortind,nreef,xlab,ylab,title,idmap)
    hold on;
    for ii=1:nreef
        ind=logical(X(:,1)==uid(sortind(ii)));
        plot(residcol(ind),ii,'k+','markersize',2);%plot the residuals
        plot(median(residcol(ind)),ii,'ro','markersize',2);%plot median residual
    end

    ytick=1:nreef;%label by reefid
    tl=get(gca,'ticklength');
    xt=get(gca,'xticklabel');
    xl=get(gca,'xlim');
    yl=[-2 nreef+3];
    if xl(1)<0%symmetrical about zero
        xm=max(abs(xl));
        xl=[-xm xm];
        plot([0 0],yl,'k:');
    end

    set(gca,'xlim',xl,'ylim',yl);
    set(gca,'ytick',ytick,'yticklabel',uid(sortind),'fontsize',6,'tickdir','out','ticklength',0.2*tl);
    xlabel(xlab,'fontsize',18);
    if ~isempty(ylab)
        ylabel(ylab,'fontsize',18);
    end
    
    if ~isempty(title)
        text(xl(1)+0.1*(xl(2)-xl(1)),yl(2),title);%,'fontsize',18);
    end
    
    %draw the grid by hand
    for ii=1:nreef
        plot(xl,[ii,ii],'color',0.95*ones(1,3));
        ind=logical(X(:,1)==uid(sortind(ii)));
        plot(residcol(ind),ii,'k+','markersize',2);%plot the residuals again so they are on top
        plot(median(residcol(ind)),ii,'ro','markersize',2);%plot median residual
    end;
    
    if ~isempty(idmap)
        ynames=idmap{1};
        set(gca,'yticklabel',ynames(uid(sortind)));
    end

end

