function [simdata,simreefid,simyear]=simulatefromstart(X0,rl,a,g,gamma,r,d,beta,Nstep,Tscale,newfig,fontsize,markersize)
%simulate SDE model with real start points and sequence lengths
%SYNTAX
%[simdata,simreefid,simyear,X0,rl]=simulatefromstart(X0,rl,a,g,gamma,r,d,beta,Nstep,Tscale,newfig,fontsize,markersize)
%INPUTS
%X0 is a matrix in which each row is an initial vector for simulation (elements coral, algae, others),
%corresponding to the start of a set of observations in consecutive years
%on a single reef in the real data
%rl is a vector in which each element is the max year for a run of the
%simulation (the number of years of consecutive
%observations after the first in the sequence commencing with the
%corresponding row of X0)
%a,g,gamma,r,d: model parameters as in Mumby et al
%beta is a vector with two elements: variance for stochastic part of coral
%and macroalgae
%Nstep is number of time steps per unit time in EM algorithm
%Tscale is the number of time units in EM algorithm per year
%newfig (optional): if 1 (default), plot on a new figure. If -1, don't plot
%at all
%fontsize (optional): font size for axis labels
%markersize (optional): marker size for points
%OUTPUTS
%simdata is a matrix in which each row is a vector of coral, algae, and
%others in a simulated reef. The initial values are those in X0 (see
%below).
%simreeefid is a vector of reef ids, such that each simulated sequence of
%consecutive observations has a unique integer id
%simyear is a vector of simulated observation times (integers from zero
%upwards)
%Also produces a ternary plot
%[0 1 0] will be at top vertex (all algae)
%[1 0 0] at RH vertex (all coral)
%[0 0 1] at LH vertex (all others)
%For each unique reef id, the starting point of each run of one-year observation intervals is plotted as a blue circle and
%the simulated final point is a red dot. Other simulated points are black dots, and they
%are joined by black lines.
%USES
%stochastic_coral2.m
%coral_triangle3.m
%NOTES
%12/4/11: rounded simyear to make sure it really is integer

if nargin<11
    newfig=1;
end
if nargin<12
    fontsize=18;
end
if nargin<13
    markersize=10;
end

nsim=length(rl);
simdata=[];
simreefid=[];%these are just labels: no match to real reef id
simyear=[];
Ns=Nstep*Tscale;
for i=1:nsim
    [t,X]=stochastic_coral2(a,g,gamma,r,d,beta,X0(i,:),Tscale*(rl(i)+1),Ns*(rl(i)+1));%simulate a sequence
    simyear=[simyear;(t(1:Ns:Ns*(rl(i)+1)))'];%save just the integer times
    simdata=[simdata;X(1:Ns:Ns*(rl(i)+1),:)];
    simreefid=[simreefid;ones(rl(i)+1,1)*i];
end
simyear=simyear/Tscale;%rescale time
simyear=round(simyear);%make sure it really is integers
if newfig~=-1
    coral_triangle3(simdata,simreefid,simyear,[],newfig,fontsize,markersize);
end
