function [t,X]=stochastic_coral2(a,g,gamma,r,d,beta,X0,T,N,fix)
%SDE version of the Mumby et al 07 coral-macroalgae-turf model, using EM
%method with Brownian increments applied to Aitchison logratio
%transformation
%This version: Brownian increments don't depend on location on the real
%transform of the simplex
%SYNTAX
%[t,X]=stochastic_coral2(a,g,gamma,r,d,beta,X0,T,N,fix)
%INPUTS
%a,g,gamma,r,d: model parameters as in Mumby et al
%beta is a vector with two elements: variance for stochastic part of coral
%and macroalgae
%X0 is initial vector (coral, algae, turf)
%T is max time to simulate the trajectory
%N is number of time steps to run
%if fix (optional, default 0) is 1, fix the pseudorandom number generator start date
%OUTPUTS
%t is the set of time points used
%X is a matrix with columns coral, macroalgae, turf for each of the times
%(rows) in t

if nargin<10
    fix=0;
end

%calculate Brownian increments
if fix
    RandStream.setDefaultStream(RandStream('mt19937ar','seed',1000));
end
dt=T/N;
dW=sqrt(dt)*randn(N,2);

%allocate space for X
X=zeros(N+1,3);

%initialize
X(1,:)=X0;
t=0:dt:T;
for j=2:N+1%for each EM step
    %update X
    C=X(j-1,1);
    M=X(j-1,2);
    U=1-C-M;
    
    
    %Using Aitchison transform for Brownian increments
    Cdet=C+(r*U*C-d*C-a*M*C)*dt;%coral deterministic
    Mdet=M+(a*M*C-g*M/(M+U)+gamma*M*U)*dt;%algae deterministic
    Udet=1-Cdet-Mdet;%turf deterministic
    CA=log(Cdet/Udet);%Aitchison transformation of deterministic
    MA=log(Mdet/Udet);
    Cinc=beta(1)*dW(j-1,1);%Brownian increment for coral
    Minc=beta(2)*dW(j-1,2);%Brownian increment for algae
    CA=CA+Cinc;
    MA=MA+Minc;
    X(j,1)=exp(CA)/(exp(CA)+exp(MA)+1);%back-transform
    X(j,2)=exp(MA)/(exp(CA)+exp(MA)+1);
    


end
X(2:end,3)=1-sum(X(2:end,:),2);

%figure(1);
%clf;
%plot(X(:,2),X(:,1),'r-');
%axis equal;
%set(gca,'xlim',[0 1],'ylim',[0 1]);
%hold on;
%plot([0 1],[1 0],'k-');
%xlabel('Macroalgae');
%ylabel('Coral');